@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 
-package TextFileParser 0.1821907;
+package TextFileParser 0.200;
 
 # ABSTRACT: an extensible Perl class to parse any text file by specifying grammar in derived classes.
 
@@ -78,18 +78,25 @@ sub __open_file {
     open my $fh, "<$fname"
         or throw_cant_open error => "Error while opening file $fname";
     $self->{__filehandle} = $fh;
+    $self->{__size} = (stat $fname)[7];
 }
 
 sub __read_file_handle {
-    my ($self) = @_;
+    my $self = shift;
     my $fh = $self->{__filehandle};
-    $self->lines_parsed(0);
+    $self->__init_read_fh;
     while (<$fh>) {
         $self->lines_parsed( $self->lines_parsed + 1 );
         $self->__try_to_parse($_);
     }
 }
 
+sub __init_read_fh {
+    my $self = shift;
+    $self->lines_parsed(0);
+    $self->{__bytes_read} = 0;
+}
+
 
 sub lines_parsed {
     my $self = shift;
@@ -156,7 +163,7 @@ TextFileParser - an extensible Perl class to parse any text file by specifying g
 
 =head1 VERSION
 
-version 0.1821907
+version 0.200
 
 =head1 SYNOPSIS
 
@@ -213,15 +220,7 @@ Takes zero or one string argument with the name of the file. Throws an exception
 
 Returns once all records have been read or if an exception is thrown for any parsing errors. This function will handle all C<open> and C<close> operations on all files even if any exception is thrown.
 
-    use Try::Tiny;
-
-    try {
-        $pars->read('myfile.txt');
-    } catch {
-        print STDERR $_, "\n";
-    }
-
-You're better-off not overriding this subroutine. Override C<save_record> instead. If you want to intervene in the file C<open> step you can't do it for now. A new version will explain how you can do that.
+B<Recommendation:> Don't override this subroutine. Override C<save_record> instead.
 
 =head2 filename
 
@@ -252,10 +251,11 @@ Here's an example of a parser that reads multi-line files: if a line starts with
 
     sub save_record {
         my ($self, $line) = @_;
+        return $self->SUPER::save_record($line) if $line !~ /^[+]\s*/;
+        $line =~ s/^[+]\s*//;
+        my $last_rec = $self->pop_record;
         chomp $last_rec;
-        return $self->SUPER::save_record($line) if $line !~ /^[+]\s+/;
-        $line =~ s/^[+]\s+//;
-        $self->SUPER::save_record( $self->pop_record . $line );
+        $self->SUPER::save_record( $last_rec . ' ' . $line );
     }
 
 =head2 get_records
@@ -282,6 +282,10 @@ Takes no arguments and returns the last saved record. In the process the last el
     $uc_last = uc $last_rec;
     $pars->save_record($uc_last);
 
+=head1 RATIONALE
+
+This text parser is mainly meant for Perl programmers to parse any arbitrary format of text file with modular code. Ideally, the part of the code related to parsing the file line-by-line, storing records, getting records, popping records, and so forth should not be repeated, and should be common to all text files. The only thing that should change is the way the format of the file is processed. This class allows for that separation.
+
 =head1 AUTHOR
 
 Balaji Ramasubramanian <balajiram@cpan.org>
